==> xoonips-3.46a.tar.gz: xoonips-3.46a/itemtypes/xnpbook/class/orm/item_type.class.php <==
<?php
// $Revision: 1.1.4.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

include_once XOOPS_ROOT_PATH . '/modules/xoonips/class/orm/item_type.class.php';

/**
 * @brief Data object of Book detail information
 */
class XNPBookOrmItemType extends XooNIpsOrmItemType
{
    function XNPBookOrmItemType() 
    {
        parent::XooNIpsOrmItemType('xnpbook');
        // detail
/* $this->fields is obsoleted. use $this->iteminfo.
        foreach($this->fields as $i => $f) {
            if ('publication_year' == $f['name']) {
                $this->fields[$i]['required'] = true;
            }
        }
*/
    }
}

/**
 * @brief handler of item type
 *
 *
 */
class XNPBookOrmItemTypeHandler extends XooNIpsOrmItemTypeHandler
{
    function XNPBookOrmItemTypeHandler(&$db) 
    {
        parent::XooNIpsOrmItemTypeHandler($db);
        $this->__initHandler('XNPBookOrmItemType', 'xoonips_item_type', 'item_type_id', false);
    }
}
?>

==> xoonips-3.50.tar.gz: xoonips-3.50/itemtypes/xnpbook/class/orm/item_type.class.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');

require_once XOOPS_ROOT_PATH.'/modules/xoonips/class/orm/item_type.class.php';

/**
 * @brief Data object of Book detail information
 */
class XNPBookOrmItemType extends XooNIpsOrmItemType
{
    public function __construct()
    {
        parent::__construct('xnpbook');
        // detail
        /* $this->fields is obsoleted. use $this->iteminfo.
        foreach($this->fields as $i => $f) {
            if ('publication_year' == $f['name']) {
                $this->fields[$i]['required'] = true;
            }
        }
        */
    }
}

/**
 * @brief handler of item type
 */
class XNPBookOrmItemTypeHandler extends XooNIpsOrmItemTypeHandler
{
    public function __construct(&$db)
    {
        parent::__construct($db);
        $this->__initHandler('XNPBookOrmItemType', 'xoonips_item_type', 'item_type_id', false);
    }
}
